@@ -4,7 +4,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.03_02';
+our $VERSION = '0.09_01';
 
 use File::Spec;
 use YAML::XS qw( LoadFile );
@@ -48,7 +48,9 @@ sub new {
 
   my $self = bless {}, $self_class;
 
-  $self->{dirs} = $params{dirs} || ['.'];
+  $self->{dirs} = $params{dirs} || [];
+  push( @{ $params{dirs} }, '.' );
+
   $self->{interpolate_variables} = exists $params{interpolate_variables}
       ? $params{interpolate_variables} : 1;
   $self->{process_directives} = exists $params{process_directives}
@@ -336,8 +338,10 @@ features
     dirs => [ qw( /etc/myapp /home/username/etc/myapp ) ],
   );
 
-  my $config = $config_processor->load(
-    qw( dirs.yml db.json metrics/* ),
+  my $config = $config_processor->load( qw( dirs.yml db.json metrics/* ) );
+
+  $config = $config_processor->load(
+    qw( dirs.yml db.json redis.yml mongodb.json metrics/* ),
 
     { myapp => {
         db => {
@@ -368,8 +372,10 @@ F<.yaml>, F<.jsn>, F<.json>.
     dirs => [ qw( /etc/myapp /home/username/etc/myapp ) ],
   );
 
+  $config_processor = Config::Processor->new();
+
   $config_processor = Config::Processor->new(
-    dirs                  => [ qw( /etc/myapp /home/username/myapp/etc ) ],
+    dirs                  => [ qw( /etc/myapp /home/username/etc/myapp ) ],
     interpolate_variables => 0,
     process_directives    => 0,
   );
@@ -378,7 +384,8 @@ F<.yaml>, F<.jsn>, F<.json>.
 
 =item dirs => \@dirs
 
-List of directories, in which configuration processor will search files.
+List of directories, in which configuration processor will search files. If
+the parameter not specified, current directory will be used.
 
 =item interpolate_variables => $boolean
 
@@ -401,6 +408,8 @@ Configuration section can be a relative filename, a filename with wildcard
 characters or a hash reference. Filenames with wildcard characters is processed
 by C<CORE::glob> function and supports the same syntax.
 
+  my $config = $config_processor->load( qw( myapp.yml extras/* ), \%hard_config );
+
 =head2 interpolate_variables( [ $boolean ] )
 
 Enables or disables variable interpolation in configurations files.
@@ -425,7 +434,7 @@ Config::Processor merges all configuration sections in one resulting configurati
 
   HASH \%a    SCALAR $b    SCALAR $b
   HASH \%a    ARRAY  \@b   ARRAY  \@b
-  HASH \%a    HASH   \%b   HASH   { %a, %b }
+  HASH \%a    HASH   \%b   HASH   recursive_merge( \%a, \%b )
 
 For example, we have two configuration files. F<db.yml> at the left side:
 
@@ -463,8 +472,9 @@ After merging of two files we will get:
 
 =head1 INTERPOLATION
 
-Config::Processor can interpolate variables in string values. For example, we
-have F<myapp.yml> file:
+Config::Processor can interpolate variables in string values (if you need alias
+for complex sctructures see C<var> directive). For example, we have
+F<myapp.yml> file:
 
   myapp:
     media_formats: [ "images", "audio", "video" ]
@@ -474,7 +484,7 @@ have F<myapp.yml> file:
       templates_dir: "${myapp.dirs.root_dir}/templates"
       sessions_dir: "${myapp.dirs.root_dir}/sessions"
       media_dirs:
-        - "${myapp.dirs.root_dir}/medis/${myapp.media_formats.0}"
+        - "${myapp.dirs.root_dir}/media/${myapp.media_formats.0}"
         - "${myapp.dirs.root_dir}/media/${myapp.media_formats.1}"
         - "${myapp.dirs.root_dir}/media/${myapp.media_formats.2}"
 
@@ -585,7 +595,7 @@ For example, you can use this directive to set default values of parameters.
           username: "stat_reader"
           password: "stat_reader_pass"
 
-You can move default parameters in separate file.
+You can move default parameters in separate files.
 
   myapp:
     db:
